.. Patent Client documentation master file, created by
   sphinx-quickstart on Wed Oct 24 10:48:07 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

* `Code on GitHub <https://github.com/parkerhancock/patent_client>`_
* `Package on PyPI <https://pypi.org/project/patent-client/>`_

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   motivation
   getting_started
   fulltext
   us_application
   assignments
   ptab
   usitc
   epo
   api
   developer/overview
   developer/design_notes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
